pygeodesy.units.Bool

Package pygeodesy :: Module units :: Class Bool |
[frames] | no frames]

# Class Bool

              object --+
                       |
                     int --+
                           |
          object --+       |
                   |       |
        named._Named --+   |
                       |   |
    unitsBase._NamedUnit --+
                           |
               unitsBase.Int --+
                               |
              object --+       |
                       |       |
            named._Named --+   |
                           |   |
        unitsBase._NamedUnit --+
                               |
                              Bool

Named `bool`, a sub-class of `int` like Python's `bool`.

Instance Methods
__bool__(self) x != 0 |
__nonzero__(self) x != 0 |
toRepr(self, std=False, **unused) Return a representation of this `Bool`. |
toStr(self, **unused) Return this `Bool` as standard `str`. |
Inherited from `unitsBase.Int`: `__repr__`, `__str__` Inherited from `int`: `__abs__`, `__add__`, `__and__`, `__cmp__`, `__coerce__`, `__div__`, `__divmod__`, `__float__`, `__floordiv__`, `__format__`, `__getattribute__`, `__getnewargs__`, `__hash__`, `__hex__`, `__index__`, `__int__`, `__invert__`, `__long__`, `__lshift__`, `__mod__`, `__mul__`, `__neg__`, `__oct__`, `__or__`, `__pos__`, `__pow__`, `__radd__`, `__rand__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rlshift__`, `__rmod__`, `__rmul__`, `__ror__`, `__rpow__`, `__rrshift__`, `__rshift__`, `__rsub__`, `__rtruediv__`, `__rxor__`, `__sub__`, `__truediv__`, `__trunc__`, `__xor__`, `bit_length`, `conjugate` Inherited from `named._Named`: `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, arg=None, name='', Error=<class 'pygeodesy.errors.UnitError'>, **name_arg) New, named `Bool`. |

Properties
Inherited from `int`: `denominator`, `imag`, `numerator`, `real` Inherited from `unitsBase._NamedUnit`: `std_repr`, `units` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, arg=None, name='', Error=<class 'pygeodesy.errors.UnitError'>, **name_arg) Static Method |
New, named `Bool`. Arguments: `cls` - This class (`Bool` or sub-class). `arg` - The value (any `type` convertable to `bool`). `name` - Optional instance name (`str`). `Error` - Optional error to raise, overriding the default UnitError. `name_arg` - Optional `name=arg` keyword argument, inlieu of separate `arg` and `name` ones. Returns: a new object with type S, a subtype of T A named Bool, `bool`-like. Raises: `Error` - Invalid `arg`. Overrides: object.__new__

### __nonzero__ (self) (Boolean test operator) |
x != 0 Overrides: int.__nonzero__ (inherited documentation)

### toRepr (self, std=False, **unused) |
Return a representation of this `Bool`. Arguments: `std` - Use the standard `repr` or the named representation (`bool`). Overrides: named._Named.toRepr Note: Use `env` variable `PYGEODESY_BOOL_STD_REPR=std` prior to `import pygeodesy` to get the standard `repr` or set property `std_repr=False` to always get the named `toRepr` representation.

### toStr (self, **unused) |
Return this `Bool` as standard `str`. Overrides: named._Named.toStr